require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

include Ach
describe "Ach file generation" do

  before(:each) do
    @structure = {}
    @structure[:bank_params] = {}
    @structure[:bank_params][:name] = "wellsfargo"
    #        bank_params[:receiving_dfi_routing_num] = BankRoutingNumber.find(25).routing_number
    @structure[:bank_params][:routing_num_immediate_yml] = "082000073"
    @structure[:bank_params][:routing_num_originating_dfi_yml] = "082000073"
    @structure[:bank_params][:tax_id_yml] = "1234567895"
    @structure[:bank_params][:file_id_yml] = "1234567895"
    @structure[:bank_params][:company_id_yml] = "1234567895"
    @structure[:bank_params][:security_header] = "security_header"
    @structure[:bank_params][:originator_status_code] = "1"
    @iterator = Ach::Iterator.new
    filename = "testfile.txt"
    bank_account_nums = []
    bank_account_nums << "10022001"
    inputs = {}
    inputs[:records] = @settlements
    inputs[:bank_data] = bank_account_nums
    file_creation_date = Date.today
    file_creation_time = DateTime.now
    @structure[:file_header_record] = {}
    @structure[:file_header_record][:file_creation_date] = file_creation_date
    @structure[:file_header_record][:file_creation_time] = file_creation_time
    @structure[:file_header_record][:company_name] = "Billfloat"
    @structure[:file_header_record][:file_id_modifier] = "A"

    batch = []
    bhr = {}
    bhr[:service_class_code] = '200'
    bhr[:company_name] = "Billfloat"
    bhr[:standard_entry_class_code] = "CCD"
    bhr[:company_entry_description] = "SETTLED"
    bhr[:effective_entry_date] = Date.today.to_s
    batch << bhr

    @structure[:batch_header_records] = batch
    
    ed = {}
    ed[:transaction_code] = "27"
    ed[:individual_name] = "test"
    ed[:individual_id] = "20"
    ed[:amount] = "100.23"
    ed[:receiving_dfi_routing_number] = "082000073"
    ed[:receiving_dfi_account_number] = "654564654564"
    ed[:loan_payment_id] = "32"
    entry_detail = []
    entry_detail << ed
    
    @iterator.stubs(:get_entry_details).returns(entry_detail)
    @observer = Ach::Observer.new
    @observer.stubs(:file_header).returns(Hash.new)
    @observer.stubs(:batch_header).returns(Hash.new)
    @observer.stubs(:batch_control).returns(Hash.new)
    @observer.stubs(:file_control).returns(Hash.new)
  end
  
  after(:all) do
    test_files = Dir.glob("#{Dir.pwd}/*.txt")
    unless test_files.empty?
      test_files.each do |f|
        if f.include?("_ach_")
          File.delete(f)
        end
      end
    end
  end
  
  it "should create ach file" do
    filename = "_ach_#{rand(999)}.txt"
    Ach::Creator.create_file(@structure,@iterator,filename)
    File.exists?(filename).should == true
  end

  it "test block count" do
    fn = Ach::Creator.block_count(10)
    fn.should_not be nil
    fn.class.name.should == "Fixnum"
    fn.should == 1
  end

  it "test mod_operation" do
    fn = Ach::Creator.mod_operation("082000073")
    fn.should==3
    fn = Ach::Creator.mod_operation("011000536")
    fn.should==6
  end
  
  it "should raise exception when no file is supplied" do
    obs = Ach::Observer.new
    expect {Ach::Parser.parse_file(nil,obs)}.should raise_error
  end

end
